@@ -102,8 +102,3 @@ bool RAWCreator::create(const QString &path, int width, int height, QImage &img)
     }
     return loaded;
 }
-
-ThumbCreator::Flags RAWCreator::flags() const
-{
-    return (Flags)(0);
-}
